@@ -1,10 +1,12 @@
 #!/usr/bin/perl
 
-use strict;
+use v5.26;
 use warnings;
 
 use Device::Chip::NoritakeGU_D;
 use Device::Chip::Adapter;
+
+use Future::AsyncAwait;
 use Getopt::Long qw( :config no_ignore_case );
 use Time::HiRes qw( sleep );
 
@@ -18,17 +20,17 @@ GetOptions(
 
 my $chip = Device::Chip::NoritakeGU_D->new( interface => $INTERFACE );
 
-$chip->mount_from_paramstr(
+await $chip->mount_from_paramstr(
    Device::Chip::Adapter->new_from_description( $ADAPTER ),
    $MOUNTPARAMS,
-)->get;
+);
 
-$chip->power(1)->get;
+await $chip->power(1);
 
-$chip->initialise->get;
+await $chip->initialise;
 
 foreach my $offset ( map { $_ * 8 } 0 .. 31 ) {
-   $chip->realtime_image_display_columns(
+   await $chip->realtime_image_display_columns(
       map {
          my $y = 16 * ( 1 + sin +($_+$offset)*TAU/128 );
 
@@ -36,5 +38,5 @@ foreach my $offset ( map { $_ * 8 } 0 .. 31 ) {
          vec( my $buf, $y, 1 ) = 1;
          scalar reverse pack "a4", $buf
       } 0 .. 127,
-   )->get;
+   );
 }
